@@ -14,7 +14,10 @@ class ChromeDriver(Driver):
             os.makedirs(self.profile, exist_ok=True)
             options.add_argument('--profile')
             options.add_argument(self.profile)
-        driver = webdriver.Chrome(options=options)
+        if self.executable_path is not None:
+            driver = webdriver.Chrome(options=options, executable_path=self.executable_path)
+        else:
+            driver = webdriver.Chrome(options=options)
         driver.set_page_load_timeout(self.timeout)
         driver.set_script_timeout(self.timeout)
         driver.implicitly_wait = self.timeout
