@@ -9,7 +9,11 @@ class UndetectedChromeDriver(Driver):
         options.add_argument('--disable-browser-side-navigation')
         if self.headless:
             options.add_argument('--headless')
-        driver = uc.Chrome(use_subprocess=True, user_data_dir=self.profile, options=options)
+        if self.executable_path is not None:
+            driver = uc.Chrome(use_subprocess=True, user_data_dir=self.profile,
+                               options=options, driver_executable_path=self.executable_path)
+        else:
+            driver = uc.Chrome(use_subprocess=True, user_data_dir=self.profile, options=options)
         driver.set_page_load_timeout(self.timeout)
         driver.set_script_timeout(self.timeout)
         driver.implicitly_wait = self.timeout
